@@ -1,4 +1,4 @@
-# parser.py
+# parsers.py
 
 import sys
 import argparse
@@ -165,7 +165,7 @@ def add_map_subparser(subparsers):
     parser = subparsers.add_parser(
         'map',
         help='map enriched transcripts',
-        description='Quantify enriched transcripts (through hybridization or PCR amplification) from parent single cell libraries. Read 1 contains cell partitioning and UMI information, and read 2 contains transcribed regions of enriched/targeted transcripts of interest. Bowtie2 (Langmead, B., et al. 2012) is used for read 2 alignment. The quantification (UMI deduplication) of enriched/targeted transcripts is powered by UMI-tools (Smith, T., et al. 2017).'
+        description='Quantify enriched transcripts (through hybridization or PCR amplification) from parent single cell libraries. Read 1 contains cell partitioning and UMI information, and read 2 contains transcribed regions of enriched/targeted transcripts of interest. BWA (Li, H. 2013) or Bowtie2 (Langmead, B., et al. 2012) is used for read 2 alignment. The quantification (UMI deduplication) of enriched/targeted transcripts is powered by UMI-tools (Smith, T., et al. 2017).'
     )
 
     parser.add_argument(
@@ -238,6 +238,17 @@ def add_map_subparser(subparsers):
         help='specify maximum number of ambiguous nucleotides allowed for read 1. The default is 3'
     )
 
+    parser.add_argument(
+        '-al',
+        '--aligner',
+        dest='aligner',
+        required=False,
+        type=str,
+        choices=['bwa', 'bowtie2'],
+        default='bwa',
+        help='specify aligner for read 2. The default is \'bwa\''
+    )
+
     parser.add_argument(
         '--mapq', '--mapping_quality',
         dest='mapq',
@@ -578,14 +589,14 @@ def add_demultiplex_subparser(subparsers):
     )
 
     parser.add_argument(
-        '-me',
-        '--method_extra',
-        dest='method_extra',
+        '-cm',
+        '--clustering_method',
+        dest='clustering_method',
         required=False,
         type=str,
         default='kmedoids',
         choices=['kmedoids', 'hdbscan'],
-        help='specify inital clustering method. The default is kmedoids'
+        help='specify inital clustering method. The default is \'kmedoids\''
     )
 
     parser.add_argument(
@@ -597,6 +608,17 @@ def add_demultiplex_subparser(subparsers):
         help='specify to visualize demultiplexing result'
     )
 
+    parser.add_argument(
+        '-vm',
+        '--visualization_method',
+        dest='visualization_method',
+        required=False,
+        type=str,
+        choices=['tsne', 'umap'],
+        default='tsne',
+        help='specify embedding method for visualization (works if \'-v\' is given). The default is \'tsne\''
+    )
+
 
 # qc
 def add_qc_subparser(subparsers):
